@@ -20,8 +20,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
 
     This code does not check and identity the certainty of data.
 
-    Parameters:
-        `Web of SymbolLearning <https://bgp.readthedocs.io/en/latest/src/bgp.html#bgp.skflow.SymbolLearning>`_
+    `Web of Symbolic Learning <https://bgp.readthedocs.io/en/latest/src/bgp.html#bgp.skflow.SymbolLearning>`_ .
 
     See Also:
         :class:`bgp.flow.BaseLoop`
@@ -37,9 +36,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
         Parameters
         ----------
         loop: str,None
-            bgp.flow.BaseLoop
-
-            ['BaseLoop', 'MultiMutateLoop', 'OnePointMutateLoop', 'DimForceLoop' ...].
+            bgp.flow.BaseLoop or ['BaseLoop', 'MultiMutateLoop', 'OnePointMutateLoop', 'DimForceLoop' ...].
         pop: int
             number of population.
         gen: int
@@ -99,7 +96,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
         n_jobs:int
             default 1, advise 6.
         batch_size:int
-            default 40, depend of machine.
+            default 40, depend on machine.
         random_state:int
             None,int.
         cal_dim:bool
@@ -152,7 +149,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
         store:bool or path
             bool or path.
         stop_condition:callable
-            stop condition on the best ind of hall, which return bool,the true means stop loop.
+            stop condition on the best individual of hall, which return bool,the true means stop loop.
 
             Examples::
 
@@ -188,7 +185,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
             sl = SymbolLearning()
             sl..fit(x,y,...)
 
-        Method 2. fit with customized pset. If need more self-definition, use one defined SymbolSet object to ``pset``.
+        Method 2. fit with customized pset. If you need more self-definition, use one defined SymbolSet object to ``pset``.
 
         Examples::
 
@@ -209,8 +206,8 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
             constants.
         x_dim: 1 or list of Dim
             the same size wih x.shape[1], default 1 is dless for all x.
-        y_dim: 1,Dim
-            dim of y.
+        y_dim: 1, Dim
+            Dim of y.
         c_dim: 1,list of Dim
             the same size wih c.shape, default 1 is dless for all c.
 
@@ -409,11 +406,11 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
 
 if __name__ == "__main__":
     # data
-    from sklearn.datasets import load_boston
+    from sklearn.datasets import fetch_california_housing
 
-    data = load_boston()
-    x = data["data"]
-    y = data["target"]
+    data = fetch_california_housing()
+    x = data["data"][:100]
+    y = data["target"][:100]
     c = [6, 3, 4]
 
     sl = SymbolLearning(loop=None, pop=50, gen=3, cal_dim=False, re_hall=2, add_coef=True, cv=1, random_state=2,
