@@ -7,15 +7,15 @@
 from mgetool.tool import tt
 
 if __name__ == "__main__":
-    from sklearn.datasets import load_iris,load_boston
+    from sklearn.datasets import load_iris, fetch_california_housing
     from bgp.skflow import SymbolLearning
     from sklearn import metrics
     from sklearn.utils import shuffle
 
     # data = load_iris()
-    data = load_boston()
-    x = data["data"]
-    y = data["target"]
+    data = fetch_california_housing()
+    x = data["data"][:100]
+    y = data["target"][:100]
     c = [1, 2, 3]
 
     #    data = pd.read_csv(r"..data/a.csv")
@@ -41,7 +41,7 @@ if __name__ == "__main__":
                         )
     tt.t
     sl.fit(x, y, c=c,
-                     # x_group=[[0, 1], [2, 3]]
+           # x_group=[[0, 1], [2, 3]]
            )
     tt.t
     tt.p
@@ -50,3 +50,18 @@ if __name__ == "__main__":
     # print(sl.expr)
 
     # top_n.to_csv(r"./re.csv")
+
+if __name__ == "__main__":
+    from sklearn.datasets import fetch_california_housing
+    from bgp.skflow import SymbolLearning
+
+    data = fetch_california_housing()
+    x = data["data"][:100]
+    y = data["target"][:100]
+    c = [1, 2, 3]
+
+    sl = SymbolLearning(loop="MultiMutateLoop", pop=500, gen=3, cal_dim=True, re_hall=2, add_coef=True, cv=1, random_state=1
+                )
+    sl.fit(x, y, c=c,x_group=[[1, 3], [0, 2], [4, 7]])
+    score = sl.score(x, y, "r2")
+    print(sl.expr)
